import type { IDS, PageQuery, PageResult } from '#/api/common';
import type { FixBorrowVO } from '#/api/eims/fixture-borrow/model';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  fixBorrowExport = '/eims/fixBorrow/export',
  fixBorrowImport = '/eims/fixBorrow/importData',
  fixBorrowList = '/eims/fixBorrow/list',
  root = '/eims/fixBorrow'
}

/**
 * 查询【工具借用】列表
 * @param query
 * @returns {*}
 */

export function listFixBorrow(params?: PageQuery) {
  return requestClient.get<PageResult<FixBorrowVO>>(Api.fixBorrowList, { params });
}

/**
 * 查询【工具借用】详细
 * @param fixId
 */
export function getFixBorrow(fixId: any) {
  return requestClient.get<FixBorrowVO>(`${Api.root}/${fixId}`);
}

/**
 * 新增【工具借用】
 * @param data
 */
export function addFixBorrow(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改【工具借用】
 * @param data
 */
export function updateFixBorrow(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除【工具借用】
 * @param fixIds
 */
export function delFixBorrow(fixIds: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${fixIds}`);
}

/**
 * 导出【工具借用】
 * @param data
 */
export function fixBorrowExport(data: any) {
  return commonExport(Api.fixBorrowExport, data);
}
